freplace

Function freplace 

pub(crate) fn freplace<'a>(s: &'a str, args: &[(&str, &str)]) -> Cow<'a, str>
Replace variables in the given string with the given dictionary.

The expected format to replace is {name}, where name is the first string in the dictionary entry tuple.