pub(crate) struct AbortableHandle {
abort_handle: RefCell<Option<AbortHandle>>,
}Expand description
A wrapper around JoinHandle that aborts the future if it is dropped
before the task ends.
The main API for this type is AbortableHandle::await_task().
Fields
abort_handle: RefCell<Option<AbortHandle>>Implementations
Sourceimpl AbortableHandle
impl AbortableHandle
Sourcepub(crate) async fn await_task<T>(
&self,
join_handle: JoinHandle<T>,
) -> Option<T>
pub(crate) async fn await_task<T>( &self, join_handle: JoinHandle<T>, ) -> Option<T>
Await the task of the given JoinHandle.
Aborts the previous task that was running, if any.
Returns None if the task was aborted before completion.