struct InnerCountedRef {
count: Cell<usize>,
on_zero: Box<dyn Fn()>,
on_non_zero: Box<dyn Fn()>,
}Fields
count: Cell<usize>The count of the reference
on_zero: Box<dyn Fn()>The function to call when the count decreases to zero.
on_non_zero: Box<dyn Fn()>The function to call when the count increases from zero.