pub(crate) struct OneshotNotifier<T = ()> {
context: &'static str,
sender: Arc<Mutex<Option<Sender<T>>>>,
}Expand description
A helper type to wait for a notification that can occur only one time.
OneshotNotifier::listen() must be called to initialize it and get a
receiver. The receiver must then be .awaited and the future will resolve
when it is notified.
The receiver will receive a signal the first time that
OneshotNotifier::notify_value() is called. Further calls to this
function will be noops until a new receiver is created.The value to return
must implement Default, as this is the value that will be sent to the
receiver when the notifier is dropped before a value is notified.
This notifier can be cloned freely and moved between threads.
It is also possible to share this notifier between tasks to make sure that a
single task is running at a time. If OneshotNotifier::listen() is called
while there is already a receiver waiting, it will be notified as if the
notifier was dropped.
Fields
context: &'static strThe context used to identify the notifier in logs.
sender: Arc<Mutex<Option<Sender<T>>>>The sender for the notification signal.
Implementations
Sourceimpl<T> OneshotNotifier<T>
impl<T> OneshotNotifier<T>
Sourceimpl<T> OneshotNotifier<T>
impl<T> OneshotNotifier<T>
Sourcepub(crate) fn listen(&self) -> OneshotNotifierReceiver<T>
pub(crate) fn listen(&self) -> OneshotNotifierReceiver<T>
Initialize this OneshotNotifier and get a receiver.
Sourcepub(crate) fn notify_value(&self, value: T)
pub(crate) fn notify_value(&self, value: T)
Notify the receiver with the given value, if any receiver is still listening.